==> tasks-v1.8.8.zip: tasks/messages/fi/base.php <==
<?php

return [
    '1 Day before' => '1 päivä ennen',
    '1 Month before' => '1 kuukausi ennen',
    '1 Week before' => '1 viikko ennen',
    '2 Days before' => '2 päivää ennen',
    '2 Weeks before' => '2 viikkoa ennen',
    '3 Weeks before' => '3 viikkoa ennen',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Määritetyt käyttäjät</strong> voivat työstää tätä tehtävää.',
    '<strong>Confirm</strong> task deletion' => '<strong>Vahvista</strong> tehtävän poistaminen',
    '<strong>Create</strong> task list' => '<strong>Luo</strong> tehtäväluettelo',
    '<strong>Edit</strong> task' => '<strong>Muokkaa</strong> tehtävää',
    '<strong>Edit</strong> task list' => '<strong>Muokkaa</strong> tehtäväluetteloa',
    '<strong>Task</strong> Overview' => '<strong>Tehtävä</strong> yleiskatsaus',
    '<strong>Your</strong> tasks' => '<strong>Tehtävät</strong>',
    'Accept Task' => 'Hyväksy tehtävä',
    'Add Deadline to space calendar' => 'Lisää määräaika sivun kalenteriin',
    'Add checkpoint...' => 'Lisää tarkistuspiste...',
    'Add reminder' => 'Lisää muistutus',
    'Add responsible users' => 'Lisää vastuuhenkilö',
    'Add schedule to the space calendar' => 'Lisää aikataulu sivun kalenteriin',
    'Add task' => 'Lisää tehtävä',
    'Add to space calendar' => 'Lisää sivun kalenteriin',
    'All Day' => 'Koko päivä',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Käyttäjä voi luoda itselleen uusia tehtäviä ja hallita niitä.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Antaa käyttäjän luoda, poistaa ja muokata tehtäviä ja listoja sekä lajitella tehtäviä ja listoja',
    'Allows the user to process unassigned tasks' => 'Sallii käyttäjän käsitellä määrittämättömiä tehtäviä',
    'Already requested' => 'Jo pyydetty',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Jokainen käyttäjä, jolla on lupa "määrittelemättömät tehtävät" , voi toimia tämän tehtävän parissa',
    'Anyone can work on this task!' => 'Jokainen voi työskennellä tämän tehtävän parissa!',
    'Assign users' => 'Määrätyt käyttäjät',
    'Assigned' => 'Määrätyt',
    'Assignment' => 'Määrätyt',
    'Assignments:' => 'Tehtävät:',
    'At least 1 Hour before' => 'Vähintään 1 tunti ennen',
    'At least 2 Hours before' => 'Vähintään 2 tuntia ennen',
    'Begin Task' => 'Aloita tehtävä',
    'Checklist Items' => 'Tarkistuslistan kohteet',
    'Checklist:' => 'Tarkistuslista:',
    'Close' => 'Sulje',
    'Color' => 'Väri',
    'Completed' => 'Valmistunut',
    'Continue Review' => 'Jatka tarkastelua',
    'Create tasks' => 'Luo tehtäviä',
    'Created by me' => 'Minun luomat',
    'Date' => 'Päivämäärä',
    'Deadline at' => 'Määräaika:',
    'Deadline: ' => 'Määräaika:',
    'Delete' => 'Poista',
    'Delete list' => 'Poista lista',
    'Description' => 'Kuvaus',
    'Do not remind' => 'Älä muistuta',
    'Do you really want to delete this task?' => 'Haluatko todella poistaa tämän tehtävän?',
    'Don\'t add to calendar' => 'Älä lisää kalenteriin',
    'Drag entry' => 'Vedä merkintä',
    'Edit' => 'Muokkaa',
    'Edit item (empty field will be removed)...' => 'Muokkaa kohdetta (tyhjä kenttä poistetaan) ...',
    'Edit list' => 'Muokkaa listaa',
    'End' => 'Päätä',
    'End Date' => 'Päättymispäivä',
    'End Time' => 'Päättymisaika',
    'End date' => 'Päättymispäivä',
    'End time must be after start time!' => 'Päättymisaika on oltava alkamisajan jälkeen!',
    'Extend deadline request' => 'Lisää määräaikaa pyynnöt',
    'Filter' => 'Suodatin',
    'Filter tasks' => 'Suodata tehtävät',
    'Finish Task' => 'Viimeistele tehtävä',
    'General' => 'Yleiset',
    'General Settings' => 'Yleiset',
    'Hide this list once all tasks are completed' => 'Piilota tämä lista, kun kaikki tehtävät on suoritettu',
    'I\'m assigned' => 'Minulle määrätyt',
    'I\'m responsible' => 'Joista olen vastuussa',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Jos et valitse käyttäjää, jokainen sivun jäsen, jolla on lupa käsitellä määrittämättömiä tehtäviä, voi käsitellä tehtävän.',
    'In Progress' => 'Meneillään',
    'In Review' => 'Tarkastelussa',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Jos tarkasteluvaihtoehto on aktiivinen, <strong>vastuu henkilö</strong> on vahvistettava tämä tehtävä ennen sen valmistumista.',
    'Invalid task list selection.' => 'Virheellinen tehtävälistan valinta.',
    'Let Task Review' => 'Anna tehtävän arvostelu',
    'Manage tasks' => 'Hallitse tehtäviä',
    'No Scheduling set for this Task' => 'Tätä tehtävää varten ei ole asetettu aikataulua',
    'No pending tasks found' => 'Ei odottavia tehtäviä',
    'No results found for the given filter.' => 'Ei tulokisa annetulla suodatimella.',
    'Open Task' => 'Avaa tehtävä',
    'Other Tasks' => 'Muut tehtävät',
    'Overdue' => 'Myöhässä',
    'Overview' => 'Sivut',
    'Parent Task' => 'Päätehtävä',
    'Pending' => 'Odottaa',
    'Pending Review' => 'Odottaa tarkistusta',
    'Process unassigned tasks' => 'Käsittele määrittämättömiä tehtäviä',
    'Ready For Review' => 'Valmis arvosteltavaksi',
    'Receive Notifications for Task Reminder.' => 'Vastaanota ilmoituksia tehtävästä.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Vastaanota ilmoituksia tehtäviin liittyen (Määräajat, tilamuutokset ...).',
    'Reject Task' => 'Hylkää tehtävä',
    'Remind Mode' => 'Muistutus',
    'Reminder' => 'Muistutus',
    'Reminder sent' => 'Muistutus lähetetty',
    'Reminders' => 'Muistutukset',
    'Request extension' => 'Pyydä lisäystä',
    'Request sent' => 'Pyyntö lähetetty',
    'Reset Task' => 'Palauta tehtävä',
    'Responsible' => 'Vastuuhenkilö',
    'Review by responsible user required' => 'Vastuu käyttäjän on tarkistettava',
    'Scheduling' => 'Aikataulutus',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Näytä {count} valmista tähtävää lisää {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Lajittelujärjestys',
    'Sort order' => 'Lajittelujärjestys',
    'Spaces' => 'Sivut',
    'Start' => 'Aloita',
    'Start Date' => 'Aloituspäivä',
    'Start Time' => 'Aloitusaika',
    'Start date' => 'Aloituspäivä',
    'Status' => 'Tila',
    'Task' => 'Tehtävä',
    'Task Users have been notified' => 'Tehtävien käyttäjiä on informoitu',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Tehtävä {task} sivulla {spaceName} päättyy {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Tehtävä {task} sivulla {spaceName} alkaa {dateTime}.',
    'Tasks' => 'Tehtävät',
    'Tasks: Reminder' => 'Tehtävien: Muistutus',
    'This task can only be processed by assigned and responsible users.' => 'Tätä tehtävää voi käsitellä vain määrätyt ja vastuuhenkilöt.',
    'This task requires to be reviewed by a responsible' => 'Tämä tehtävä edellyttää, että vastuu henkilö tarkistaa tämän tehtävän',
    'Time Zone' => 'Aikavyöhyke',
    'Title' => 'Otsikko',
    'Title and Color' => 'Otsikko ja väri',
    'Today' => 'Tänään',
    'Unsorted' => 'Lajittelemattomat',
    'View Online' => 'Näytä selaimessa',
    'You are assigned!' => 'Olet määrätty!',
    'You are responsible!' => 'Olet vastuussa!',
    'You have insufficient permissions to perform that operation!' => 'Sinulla ei ole riittävästi oikeuksia suorittaa tätä toimintoa!',
    'Your Reminder for task {task}' => 'Muistutus tehtävästä {task}',
    'ending Review' => 'päättyvä tarkastus',
    'view all' => 'näytä kaikki',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# päivä} other{# päivää}} jäljellä',
    '{displayName} is assigned to this task' => '{displayName} on määrätty tähän tehtävään',
    '{displayName} is responsible for this task' => '{displayName} vastuussa tästä tehtävästä',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} antoi sinulle vastuuhenkilön tehtävän tehtävään {task} sivulla {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} antoi sinulle tehtävän {task} sivulla {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} suoritti tehtävän {task} sivulla {spaceName}.',
    '{userName} completed task {task}.' => '{userName} suoritti tehtävän {task}.',
    '{userName} finished task {task}.' => '{userName} sai tehtävän {task} valmiiksi.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} vaihtoi määräaikaa tehtävässä {task} sivulla {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} avasi tehtävän {task} uudelleen sivulla {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} on hylännyt tehtävän {task} sivulla {spaceName} suorittamattomana.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} on merkinnyt tehtävän {task} sivulla {spaceName} valmiiksi.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} pyytää tehtävän {task} määräajan pidennystä {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} pyytää sinua tarkastamaan tehtävää {task} avaruudessa {spaceName}.',
    '{userName} reset task {task}.' => '{userName} palautti tehtävän {task}.',
    '{userName} reviewed task {task}.' => '{userName} tarkasteli tehtävää {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} alkoi työskennellä tehtävää {task} sivulla {spaceName}.',
    '{userName} works on task {task}.' => '{userName} työstää tehtävää {task}.',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/fi/base.php <==
<?php

return [
    '1 Day before' => '1 päivä ennen',
    '1 Month before' => '1 kuukausi ennen',
    '1 Week before' => '1 viikko ennen',
    '2 Days before' => '2 päivää ennen',
    '2 Weeks before' => '2 viikkoa ennen',
    '3 Weeks before' => '3 viikkoa ennen',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Määritetyt käyttäjät</strong> voivat työstää tätä tehtävää.',
    '<strong>Confirm</strong> task deletion' => '<strong>Vahvista</strong> tehtävän poistaminen',
    '<strong>Create</strong> task list' => '<strong>Luo</strong> tehtäväluettelo',
    '<strong>Edit</strong> task' => '<strong>Muokkaa</strong> tehtävää',
    '<strong>Edit</strong> task list' => '<strong>Muokkaa</strong> tehtäväluetteloa',
    '<strong>Task</strong> Overview' => '<strong>Tehtävä</strong> yleiskatsaus',
    '<strong>Your</strong> tasks' => '<strong>Tehtävät</strong>',
    'Accept Task' => 'Hyväksy tehtävä',
    'Add Deadline to space calendar' => 'Lisää määräaika sivun kalenteriin',
    'Add checkpoint...' => 'Lisää tarkistuspiste...',
    'Add reminder' => 'Lisää muistutus',
    'Add responsible users' => 'Lisää vastuuhenkilö',
    'Add schedule to the space calendar' => 'Lisää aikataulu sivun kalenteriin',
    'Add task' => 'Lisää tehtävä',
    'Add to space calendar' => 'Lisää sivun kalenteriin',
    'All Day' => 'Koko päivä',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Käyttäjä voi luoda itselleen uusia tehtäviä ja hallita niitä.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Antaa käyttäjän luoda, poistaa ja muokata tehtäviä ja listoja sekä lajitella tehtäviä ja listoja',
    'Allows the user to process unassigned tasks' => 'Sallii käyttäjän käsitellä määrittämättömiä tehtäviä',
    'Already requested' => 'Jo pyydetty',
    'Assign users' => 'Määrätyt käyttäjät',
    'Assignment' => 'Määrätyt',
    'At least 1 Hour before' => 'Vähintään 1 tunti ennen',
    'At least 2 Hours before' => 'Vähintään 2 tuntia ennen',
    'Begin Task' => 'Aloita tehtävä',
    'Checklist Items' => 'Tarkistuslistan kohteet',
    'Checklist:' => 'Tarkistuslista:',
    'Close' => 'Sulje',
    'Color' => 'Väri',
    'Completed' => 'Valmistunut',
    'Continue Review' => 'Jatka tarkastelua',
    'Create tasks' => 'Luo tehtäviä',
    'Created by me' => 'Minun luomat',
    'Date' => 'Päivämäärä',
    'Deadline: ' => 'Määräaika:',
    'Delete' => 'Poista',
    'Delete list' => 'Poista lista',
    'Description' => 'Kuvaus',
    'Do not remind' => 'Älä muistuta',
    'Do you really want to delete this task?' => 'Haluatko todella poistaa tämän tehtävän?',
    'Don\'t add to calendar' => 'Älä lisää kalenteriin',
    'Edit' => 'Muokkaa',
    'Edit item (empty field will be removed)...' => 'Muokkaa kohdetta (tyhjä kenttä poistetaan) ...',
    'Edit list' => 'Muokkaa listaa',
    'End' => 'Päätä',
    'End Date' => 'Päättymispäivä',
    'End Time' => 'Päättymisaika',
    'End date' => 'Päättymispäivä',
    'End time must be after start time!' => 'Päättymisaika on oltava alkamisajan jälkeen!',
    'Extend deadline request' => 'Lisää määräaikaa pyynnöt',
    'Filter' => 'Suodatin',
    'Filter tasks' => 'Suodata tehtävät',
    'Finish Task' => 'Viimeistele tehtävä',
    'General' => 'Yleiset',
    'General Settings' => 'Yleiset',
    'Hide this list once all tasks are completed' => 'Piilota tämä lista, kun kaikki tehtävät on suoritettu',
    'I\'m assigned' => 'Minulle määrätyt',
    'I\'m responsible' => 'Joista olen vastuussa',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Jos et valitse käyttäjää, jokainen sivun jäsen, jolla on lupa käsitellä määrittämättömiä tehtäviä, voi käsitellä tehtävän.',
    'In Progress' => 'Meneillään',
    'In Review' => 'Tarkastelussa',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Jos tarkasteluvaihtoehto on aktiivinen, <strong>vastuu henkilö</strong> on vahvistettava tämä tehtävä ennen sen valmistumista.',
    'Invalid task list selection.' => 'Virheellinen tehtävälistan valinta.',
    'Let Task Review' => 'Anna tehtävän arvostelu',
    'Manage tasks' => 'Hallitse tehtäviä',
    'No Scheduling set for this Task' => 'Tätä tehtävää varten ei ole asetettu aikataulua',
    'No pending tasks found' => 'Ei odottavia tehtäviä',
    'No results found for the given filter.' => 'Ei tulokisa annetulla suodatimella.',
    'Open Task' => 'Avaa tehtävä',
    'Other Tasks' => 'Muut tehtävät',
    'Overdue' => 'Myöhässä',
    'Overview' => 'Sivut',
    'Parent Task' => 'Päätehtävä',
    'Pending' => 'Odottaa',
    'Pending Review' => 'Odottaa tarkistusta',
    'Process unassigned tasks' => 'Käsittele määrittämättömiä tehtäviä',
    'Ready For Review' => 'Valmis arvosteltavaksi',
    'Receive Notifications for Task Reminder.' => 'Vastaanota ilmoituksia tehtävästä.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Vastaanota ilmoituksia tehtäviin liittyen (Määräajat, tilamuutokset ...).',
    'Reject Task' => 'Hylkää tehtävä',
    'Remind Mode' => 'Muistutus',
    'Reminder' => 'Muistutus',
    'Reminder sent' => 'Muistutus lähetetty',
    'Reminders' => 'Muistutukset',
    'Request extension' => 'Pyydä lisäystä',
    'Request sent' => 'Pyyntö lähetetty',
    'Reset Task' => 'Palauta tehtävä',
    'Responsible' => 'Vastuuhenkilö',
    'Review by responsible user required' => 'Vastuu käyttäjän on tarkistettava',
    'Scheduling' => 'Aikataulutus',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Näytä {count} valmista tähtävää lisää {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Lajittelujärjestys',
    'Sort order' => 'Lajittelujärjestys',
    'Spaces' => 'Sivut',
    'Start' => 'Aloita',
    'Start Date' => 'Aloituspäivä',
    'Start Time' => 'Aloitusaika',
    'Start date' => 'Aloituspäivä',
    'Status' => 'Tila',
    'Task' => 'Tehtävä',
    'Task Users have been notified' => 'Tehtävien käyttäjiä on informoitu',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Tehtävä {task} sivulla {spaceName} päättyy {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Tehtävä {task} sivulla {spaceName} alkaa {dateTime}.',
    'Tasks' => 'Tehtävät',
    'Tasks: Reminder' => 'Tehtävien: Muistutus',
    'This task requires to be reviewed by a responsible' => 'Tämä tehtävä edellyttää, että vastuu henkilö tarkistaa tämän tehtävän',
    'Time Zone' => 'Aikavyöhyke',
    'Title' => 'Otsikko',
    'Title and Color' => 'Otsikko ja väri',
    'Today' => 'Tänään',
    'Unsorted' => 'Lajittelemattomat',
    'View Online' => 'Näytä selaimessa',
    'You have insufficient permissions to perform that operation!' => 'Sinulla ei ole riittävästi oikeuksia suorittaa tätä toimintoa!',
    'Your Reminder for task {task}' => 'Muistutus tehtävästä {task}',
    'view all' => 'näytä kaikki',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# päivä} other{# päivää}} jäljellä',
    '{displayName} is assigned to this task' => '{displayName} on määrätty tähän tehtävään',
    '{displayName} is responsible for this task' => '{displayName} vastuussa tästä tehtävästä',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} antoi sinulle vastuuhenkilön tehtävän tehtävään {task} sivulla {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} antoi sinulle tehtävän {task} sivulla {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} suoritti tehtävän {task} sivulla {spaceName}.',
    '{userName} completed task {task}.' => '{userName} suoritti tehtävän {task}.',
    '{userName} finished task {task}.' => '{userName} sai tehtävän {task} valmiiksi.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} vaihtoi määräaikaa tehtävässä {task} sivulla {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} avasi tehtävän {task} uudelleen sivulla {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} on hylännyt tehtävän {task} sivulla {spaceName} suorittamattomana.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} on merkinnyt tehtävän {task} sivulla {spaceName} valmiiksi.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} pyytää tehtävän {task} määräajan pidennystä {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} pyytää sinua tarkastamaan tehtävää {task} avaruudessa {spaceName}.',
    '{userName} reset task {task}.' => '{userName} palautti tehtävän {task}.',
    '{userName} reviewed task {task}.' => '{userName} tarkasteli tehtävää {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} alkoi työskennellä tehtävää {task} sivulla {spaceName}.',
    '{userName} works on task {task}.' => '{userName} työstää tehtävää {task}.',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignments' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Request Review' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
    '{displayName} is task creator' => '',
];
